#
# spec file for package ispell
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ispell
BuildRequires:  bison
BuildRequires:  ncurses-devel
BuildRequires:  words
Url:            http://www.lasr.cs.ucla.edu/geoff/ispell.html
PreReq:         fillup fileutils
Provides:       spell
Requires:       ispell_dictionary
Requires:       ispell_english_dictionary
Requires:       words
Version:        3.3.02
Release:        116.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        A Spell Checker
License:        BSD-3-Clause
Group:          Productivity/Text/Spell
Source:         ispell-3.3.02.tar.bz2
Source1:        SuSEconfig.ispell
Source2:        sysconfig.ispell
Patch0:         ispell-3.3.02.dif
Patch1:         ispell-3.3.02-config.patch
Patch2:         ispell-3.2.06-suse.patch
Patch3:         ispell-3.3.02-languages.patch
Patch4:         ispell-3.3.02-types.patch
Patch5:         ispell-3.3.02-terminal.patch
Patch6:         ispell-3.3.02-sq.patch
Patch7:         ispell-3.3.02-brkgcc.patch
Patch8:         ispell-3.3.02-mkdir.patch
Patch9:         ispell-3.3.02-strip.patch
Patch10:        ispell-3.3.02-getline.patch
# PATCH-FIX-OPENSUSE correct typo (boo#966124)
Patch11:        boo966124.dif

%description
Ispell is a fast, screen-oriented spell checker that shows you your
errors in the context of the original file and suggests possible
corrections when it can figure them out.  Compared to UNIX spell, it is
faster and much easier to use.	Ispell can also handle languages other
than English.  Ispell has a long history and many people have
contributed to the current version--some of the major contributors
include R. E. Gorin, Pace Willisson, Walt Buehring, and Geoff Kuenning.

You can find a short description in the directory
/usr/share/doc/packages/ispell/.



Authors:
--------
    R. E. Gorin
    Pace Willisson <pace@ai.mit.edu>
    Walt Buehring
    Goeff Kuenning <geoff@ITcorp.com>

%package     -n ispell-american
Summary:        American ispell dictionary
Group:          Productivity/Text/Spell
Provides:       iamerica
Provides:       ispell_dictionary
Provides:       ispell_english_dictionary
Provides:       locale(ispell:en)
Obsoletes:      iamerica

%description -n ispell-american
This package includes a ready American dictionary for ispell. If you
install ispell-british too, check /etc/sysconfig/ispell to see which
one the default English dictionary will be. A short usage description
is given in /usr/share/doc/packages/ispell/README. The sources for this
dictionary are included in the source package of ispell.



%package     -n ispell-british
Summary:        British ispell dictionary
Group:          Productivity/Text/Spell
Provides:       ibritish
Provides:       ispell_dictionary
Provides:       ispell_english_dictionary
Provides:       locale(ispell:en_GB)
Obsoletes:      ibritish

%description -n ispell-british
This packages includes a ready British dictionary for ispell. If you
install ispell-american too, check /etc/sysconfig/ispell to see which
one will be the default English dictionary. A short usage description
is given in /usr/share/doc/packages/ispell/README. The sources for this
dictionary are included in the source package of ispell.



%prep
%setup
%patch -P 0 -p 0 -b .dif
%patch -P 1 -p 0 -b .config
%patch -P 2 -p 0 -b .suse
%patch -P 3 -p 0 -b .languages
%patch -P 4 -p 0 -b .types
%patch -P 5 -p 0 -b .terminal
%patch -P 6 -p 0 -b .sq
%patch -P 7 -p 0 -b .brkgcc
%patch -P 8 -p 0 -b .mkdir
%patch -P 9 -p 0 -b .strip
%patch10 -p 0 -b .gln
%patch11 -p 0 -b .typo

%build
  PATH=$PATH:$PWD
  export PATH
  make local.h
  make config.sh
  sed "s@\(DIR=\)['\"]\?\([^'\"]*\)['\"]\?@\1\"\$\{DESTDIR\}\2\"@g" \
	< config.sh > config.tmp
  mv config.tmp config.sh
  make all

%install
  DESTDIR=%{buildroot}
  export DESTDIR
  mkdir -p %{buildroot}/usr/doc/packages/ispell
  mkdir -p %{buildroot}%{_libexecdir}/ispell/emacs
  mkdir -p %{buildroot}/var/adm/fillup-templates
  mkdir -p %{buildroot}/var/lib/dict
  make install DESTDIR=%{buildroot}
  rm -f %{buildroot}/usr/share/emacs/site-lisp/ispell.el*
  install -m 0444 suse/ispell-emacs-menu.el 	%{buildroot}%{_libexecdir}/ispell/
  install -m 0444 suse/emacs/american.el	%{buildroot}%{_libexecdir}/ispell/emacs/
  install -m 0444 suse/emacs/british.el		%{buildroot}%{_libexecdir}/ispell/emacs/
  install -m 0444 suse/emacs/english.el		%{buildroot}%{_libexecdir}/ispell/emacs/
  rm -f %{buildroot}%{_libexecdir}/ispell/british.hash
  rm -r %{buildroot}%{_libexecdir}/ispell/american.hash
  ln -sf britishxlg.hash  %{buildroot}%{_libexecdir}/ispell/british.hash
  ln -sf americanxlg.hash %{buildroot}%{_libexecdir}/ispell/american.hash
  mv %{buildroot}%{_libexecdir}/ispell/english.aff %{buildroot}%{_libexecdir}/ispell/american.aff
  cp -a %{buildroot}%{_libexecdir}/ispell/american.aff %{buildroot}%{_libexecdir}/ispell/british.aff
  install -m 755 %{S:1} %{buildroot}%{_libexecdir}/ispell/update
  install -m 644 %{S:2} %{buildroot}/var/adm/fillup-templates/
  mkdir -p %{buildroot}/var/lib/dict
  ln -sf %{_libexecdir}/ispell/american.hash %{buildroot}/var/lib/dict/english.hash
  ln -sf %{_libexecdir}/ispell/american.aff  %{buildroot}/var/lib/dict/english.aff
  rm -f  %{buildroot}%{_libexecdir}/ispell/english.hash
  rm -f  %{buildroot}%{_libexecdir}/ispell/english.aff
  ln -sf /var/lib/dict/english.hash    %{buildroot}%{_libexecdir}/ispell/
  ln -sf /var/lib/dict/english.aff     %{buildroot}%{_libexecdir}/ispell/
  rm -f %{buildroot}%{_bindir}/defmt-*

%post
%{fillup_only}

%post -n ispell-american
if test -z "$YAST_IS_RUNNING" -a -x %{_libexecdir}/ispell/update ; then
    %{_libexecdir}/ispell/update
fi

%postun -n ispell-american
if test -z "$YAST_IS_RUNNING" -a -x %{_libexecdir}/ispell/update ; then
    %{_libexecdir}/ispell/update
fi

%post -n ispell-british
if test -z "$YAST_IS_RUNNING" -a -x %{_libexecdir}/ispell/update ; then
    %{_libexecdir}/ispell/update
fi

%postun -n ispell-british
if test -z "$YAST_IS_RUNNING" -a -x %{_libexecdir}/ispell/update ; then
    %{_libexecdir}/ispell/update
fi

%files
%defattr(-, root, root)
%doc suse/LIESMICH suse/README
%dir %{_libexecdir}/ispell
%{_bindir}/buildhash
%{_bindir}/findaffix
%{_bindir}/icombine
%{_bindir}/ijoin
%{_bindir}/ispell
%{_bindir}/munchlist
%{_bindir}/sq
%{_bindir}/tryaffix
%{_bindir}/unsq
%{_libexecdir}/ispell/ispell-emacs-menu.el
%dir %{_libexecdir}/ispell/emacs
%{_libexecdir}/ispell/emacs/english.el
%{_libexecdir}/ispell/english.hash
%{_libexecdir}/ispell/english.aff
%attr(0755,root,root) %{_libexecdir}/ispell/update
/var/adm/fillup-templates/sysconfig.ispell
%verify(not link mtime) /var/lib/dict/english.hash
%verify(not link mtime) /var/lib/dict/english.aff 
%doc %{_mandir}/man1/buildhash.1.gz
%doc %{_mandir}/man1/findaffix.1.gz
%doc %{_mandir}/man1/ispell.1.gz
%doc %{_mandir}/man1/munchlist.1.gz
%doc %{_mandir}/man1/sq.1.gz
%doc %{_mandir}/man1/tryaffix.1.gz
%doc %{_mandir}/man1/unsq.1.gz
%doc %{_mandir}/man5/english.5.gz
%doc %{_mandir}/man5/ispell.5.gz

%files -n ispell-american
%defattr(-, root, root)
%{_libexecdir}/ispell/american.hash
%{_libexecdir}/ispell/americanmed.hash
%{_libexecdir}/ispell/americanxlg.hash
%{_libexecdir}/ispell/emacs/american.el
%{_libexecdir}/ispell/american.aff

%files -n ispell-british
%defattr(-, root, root)
%{_libexecdir}/ispell/british.hash
%{_libexecdir}/ispell/britishmed.hash
%{_libexecdir}/ispell/britishxlg.hash
%{_libexecdir}/ispell/emacs/british.el
%{_libexecdir}/ispell/british.aff

%changelog
* Tue Nov 22 2016 werner@suse.de
- Extend patch boo966124.dif for bug boo#1010330
* Mon May 30 2016 werner@suse.de
- Extend patch boo966124.dif for bug boo#981024
* Fri Feb 12 2016 werner@suse.de
- Add patch boo966124.dif that is correct typo in english.3 word
  list (boo#966124)
* Mon Aug 17 2015 werner@suse.de
- Add changes from openSUSE to fix e.g. bsc#941760
* Tue Feb 10 2015 werner@suse.de
- Xemacs knows about define-coding-system-alia therefore use it (boo#896947)
* Wed Feb  4 2015 werner@suse.de
- Use real POSIX shell syntax
- Fix ispell update script thas is do not try to source old SUSE
  config files (boo#916001)
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashism in SuSEconfig.ispell (update) script
* Mon Dec  9 2013 werner@suse.de
- Remove mixed patch leftover
* Fri Dec  6 2013 werner@suse.de
- Hint from Björn Jacke that old style sort is broken, therefore
  enforce usage of modern sort options
* Mon Jun 18 2012 werner@suse.de
- Rename and relocate SuSEconfig.ispell
* Wed Feb  1 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Fri Aug 20 2010 werner@suse.de
- Run SuSEconfig.ispell if YaST is not used to make sure that we
  have an english dictionary
* Sun Aug 30 2009 coolo@novell.com
- provide Patch0
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Thu May 31 2007 werner@suse.de
- Update ispell to version 3.3.02 including various bug fixes
  and add new old html parser and support for UTF-8.
* Thu May 31 2007 werner@suse.de
- Fix sq/unsq, hint from Thomas Rachel
* Thu Mar 29 2007 rguenther@suse.de
- Add bison and ncurses-devel BuildRequires.
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Mar 29 2006 werner@suse.de
- Add locale provides (bug #161478)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 werner@suse.de
- Fix dangling symlink (bug #142828)
* Fri Jul  1 2005 werner@suse.de
- Make it build-root and no norootforbuild
* Thu Jun  2 2005 mfabian@suse.de
- fix ispell-emacs-menu.el for XEmacs 21.5.20 and
  xemacs-packages-20050505 (coding system iso-8859-14 may not
  exist without requiring 'latin-euro-latin8).
* Thu Mar 10 2005 werner@suse.de
- Use /var/lib/dict/ to handle ro /usr/share/dict/ and the symbolic
  link `english.hash/aff' to the choosen dictionary (bug #67048)
* Tue Dec 21 2004 werner@suse.de
- Be sure that the string utils uses the POSIX locale
* Mon May  3 2004 werner@suse.de
- Add break condition for checking HUGE lines to avoid side effect
  of the new ``compensate for short copy strategy'' (bug #39745)
* Thu Jan  8 2004 ro@suse.de
- fix build with current bison
* Fri Aug 29 2003 werner@suse.de
- More about new POSIX sort behaviour: one fix in munchlist
  and four fixes in findaffix (bug #29627).
* Thu Aug 28 2003 mmj@suse.de
- Add sysconfig metadata [#28885]
* Thu Jul 24 2003 werner@suse.de
- Fix encode mappings for Xemacs
* Tue Apr  8 2003 werner@suse.de
- Fix munchlist sort using
- Fix Makefile's sort using
- Use secure tmp directory for munchlist
* Tue Apr  8 2003 werner@suse.de
- Use -n option for tail
- Use iso-latin-1 even for english dictionaries to avoid splits
- Add some more comments about new german and the DICTIONARY var
* Thu Feb 20 2003 mmj@suse.de
- Add sysconfig metadata [#22650]
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 15 2002 ro@suse.de
- fixed typo in specfile
* Thu Aug 15 2002 werner@suse.de
- Add pre-requires (bug #17885)
* Mon May 13 2002 egmont@suselinux.hu
- use RC_LANG instead of obsolete DEFAULT_LANGUAGE
* Tue Apr 16 2002 adrian@suse.de
- add Provides spell (kdelibs3 needs either ispell or aspell now)
* Thu Mar  7 2002 egmont@suselinux.hu
- Fixed template comment
* Wed Feb 20 2002 werner@suse.de
- Avoid circular depndencies (bug #13609)
* Mon Feb  4 2002 egmont@suselinux.hu
- SuSE GmbH -> SuSE Linux AG
* Thu Jan 24 2002 werner@suse.de
- Make MASKTYPE to a string (thanks to Jan Cihlar)
* Wed Jan 16 2002 egmont@suselinux.hu
- Rename packages to ispell-american and ispell-british
- They no longer have common files, no longer exclude each other
- New SuSEconfig module to generate the "english" symlinks
* Thu Dec 13 2001 werner@suse.de
- Fix the sq patch gets versus fgets, the newline problem (#12461)
- No backslashspace patch anymore required
* Thu Sep 27 2001 werner@suse.de
- Update to ispell 3.2.06
  * port missed patches to 3.2.06
  * curent missing patches are
    ISO part of html mode and maybe backslashspace workaround
* Thu May 17 2001 werner@suse.de
- Mask all exit status with true on unlinking english.hash
* Mon May 14 2001 werner@suse.de
- Be sure that exit status is true in preun scripts
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Wed Feb  7 2001 werner@suse.de
- Workaround for broken gcc on IA64
- Split main dif into several patches
- Add backslash space patch for TeX text
- Add iso-more-html patch for HTML text
* Wed Jan 10 2001 werner@suse.de
- Make temporary files more secure
* Sat Oct 14 2000 schwab@suse.de
- Do not define bcopy and bzero on Linux.
* Mon Sep 18 2000 werner@suse.de
- Change ispell-emacs-menu.el to fit filter feature
  in ispell-menu-xemacs of newer ispell.el of XEmacs
  - Change ispell-emacs-menu.el to add local used
  dictionary list.
* Sat May 27 2000 kukuk@suse.de
- Use doc macro
* Mon Mar 13 2000 werner@suse.de
- Use tc[sg]etattr if possible
  - Use correct pointer size depending on __WORDSIZE
  - Fix common names with ncurses
  - Use $RPM_OPT_FLAGS
  - Use correct type for {m,re}alloc
  - Don't require ispell for ibritish and iamerica because
  ispell requires one of those packages (bootstrapping)
* Fri Feb 25 2000 kukuk@suse.de
- Move /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 20 1999 ro@suse.de
- added Requires ispell_dictionary for ispell
- added Provides ispell_dictionary for ibritish, iamerica
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jul 14 1999 werner@suse.de
- Avoid load messages during rebuild of emacs spell menue
* Thu Mar  4 1999 werner@suse.de
- Preparing for a better (x)emacs interface: Implement a
  emacs lisp file to create the spell menus modular on the
  fly in both emacs and xemacs Edit pulldown.
* Fri Nov 13 1998 bs@suse.de
- fixed spec file (double entry Summary)
* Thu Nov 12 1998 bs@suse.de
- fixed spec file for new rpm.
* Thu Sep 10 1998 ro@suse.de
- catch redefinition of strcmp in ijoin.c
* Thu Jul  9 1998 werner@suse.de
- Some preun scripts for ibritish and iamerica
* Wed Jul  8 1998 werner@suse.de
- Split ispell into ispell for binaries and two
  packages ibritish and iamerica (excluding each other)
* Fri Feb  6 1998 werner@suse.de
- Move hk2-deutsch to igerman and dicts package
  - Fix flag handling (flags [\]^_` are not reconginzed by isalpha)
  - Fix bug in fix8bit (wrong handling of second figure of a hex number)
* Fri Oct 17 1997 werner@suse.de
- Move description from pac to /usr/doc/packages/ispell
  - Fix ispell.texinfo
* Thu Feb  6 1997 werner@suse.de
- Repacked
  - A small modification: Now there is an environment variable
  CHARSET which will be used if and only if the environment variable
  DICTIONARY is set. E.g. DICTIONARY=deutsch and CHARSET=latin1
  Therefore `-T' is not needed ... `-n', `-t' and `-T'
    overwrites CHARSET.
